@@ -21,7 +21,7 @@ from aiohttp import web
 from pathlib import Path
 from importlib import resources   # Py≥3.9  (pip install importlib_resources for 3.7/3.8)
 
-VERSION = "2.0.7"
+VERSION = "2.0.8"
 _ROOT = None
 g_config_path = None
 g_ui_path = None
@@ -219,7 +219,13 @@ class OpenAiProvider:
         self.api_key = api_key
         self.models = models
 
-        self.chat_url = f"{base_url}/v1/chat/completions"
+        # check if base_url ends with /v{\d} to handle providers with different versions (e.g. z.ai uses /v4)
+        last_segment = base_url.rsplit('/',1)[1]
+        if last_segment.startswith('v') and last_segment[1:].isdigit():
+            self.chat_url = f"{base_url}/chat/completions"
+        else:
+            self.chat_url = f"{base_url}/v1/chat/completions"
+
         self.headers = kwargs['headers'] if 'headers' in kwargs else {
             "Content-Type": "application/json",
         }
